@@ -8,15 +8,16 @@
 #
 # See the LICENSE file in the source distribution for further information.
 
-from sos.report.plugins import Plugin, RedHatPlugin, DebianPlugin, UbuntuPlugin
+from sos.report.plugins import Plugin, IndependentPlugin
 
 
-class Cockpit(Plugin, RedHatPlugin, DebianPlugin, UbuntuPlugin):
+class Cockpit(Plugin, IndependentPlugin):
 
     short_desc = 'Cockpit Web Service'
 
     plugin_name = 'cockpit'
     packages = ('cockpit-ws', 'cockpit-system')
+    services = ('cockpit',)
 
     def setup(self):
         self.add_copy_spec([
@@ -26,6 +27,4 @@ class Cockpit(Plugin, RedHatPlugin, DebianPlugin, UbuntuPlugin):
 
         self.add_cmd_output('remotectl certificate')
 
-        self.add_journal(units='cockpit')
-
 # vim: set et ts=4 sw=4 :
