@@ -6,16 +6,16 @@
 #
 # See the LICENSE file in the source distribution for further information.
 
-from sos.report.plugins import Plugin, RedHatPlugin, DebianPlugin, UbuntuPlugin
+from sos.report.plugins import Plugin, IndependentPlugin
 
 
-class Fwupd(Plugin, RedHatPlugin, DebianPlugin, UbuntuPlugin):
+class Fwupd(Plugin, IndependentPlugin):
 
     short_desc = 'fwupd information'
 
     plugin_name = 'fwupd'
     profiles = ('system', )
-
+    services = ('fwupd',)
     packages = ('fwupd',)
 
     def setup(self):
@@ -31,19 +31,17 @@ class Fwupd(Plugin, RedHatPlugin, DebianPlugin, UbuntuPlugin):
 
         self.add_copy_spec("/etc/fwupd")
 
-        self.add_journal(units="fwupd")
-
     def postproc(self):
         self.do_path_regex_sub(
             "/etc/fwupd/remotes.d/*",
-            r"Password=(.*)",
-            r"Password=********"
+            r"(Password)=(.*)",
+            r"\1=********"
         )
 
         self.do_file_sub(
             "/etc/fwupd/redfish.conf",
-            r"Password=(.*)",
-            r"Password=********"
+            r"(Password)=(.*)",
+            r"\1=********"
         )
 
 
